@@ -2,9 +2,6 @@
 
 from pathlib import Path
 
-import numpy as np
-from nicegui import ui
-
 from oe_python_template.utils import BasePageBuilder, GUILocalFilePicker
 
 from ._service import Service
@@ -12,13 +9,17 @@ from ._service import Service
 
 async def pick_file() -> None:
     """Open a file picker dialog and show notifier when closed again."""
-    result = await GUILocalFilePicker(str(Path.cwd() / "examples"), multiple=True)
+    from nicegui import ui  # noqa: PLC0415
+    
+    result = await GUILocalFilePicker(str(Path.cwd() / "examples"), multiple=True)  # type: ignore
     ui.notify(f"You chose {result}")
 
 
 class PageBuilder(BasePageBuilder):
     @staticmethod
     def register_pages() -> None:
+        from nicegui import ui  # noqa: PLC0415
+
         @ui.page("/")
         def page_index() -> None:
             """Homepage of GUI."""
@@ -32,7 +33,9 @@ class PageBuilder(BasePageBuilder):
 
             from importlib.util import find_spec  # noqa: PLC0415
 
-            if find_spec("matplotlib"):
+            if find_spec("matplotlib") and find_spec("numpy"):
+                import numpy as np  # noqa: PLC0415
+
                 with ui.card().tight().mark("CARD_PLOT"):  # noqa: SIM117
                     with ui.matplotlib(figsize=(4, 3)).figure as fig:
                         x = np.linspace(0.0, 5.0)
